import React from 'react';
import Checkbox from '../checkbox';
import { PaginationProps } from '../pagination/PaginationProps';
import { SelectOption } from '../select/SelectProps';
type ExtendOption = {
    [key: string]: any;
};
interface Translation {
    sortTooltipAscend?: string;
    sortTooltipDescend?: string;
    sortTooltipCancel?: string;
    noData?: string;
    noGroupData?: string;
    search?: string;
    reset?: string;
    colFilter?: string;
    checkboxSelection?: string;
    showAll?: string;
    hideAll?: string;
    rowFilter?: string;
    column?: string;
    operator?: string;
    value?: string;
    group?: string;
    resetFilterBtn?: string;
    export?: string;
    exportCSV?: string;
    exportPDF?: string;
}
interface ControlCommon {
    translation?: Translation;
    showControlTitle?: boolean;
}
export interface ControlState {
    sorting: Sorting[];
    keyword: string;
    filters: Filter[];
}
type OnFilterValue = ControlState & {
    hiddenCols: string[];
};
export interface SortOptions {
    /** Sort function for ascending sort, see Array.sort's compareFunction */
    compare?: (a: any, b: any) => number;
    /** Config the priority of sort columns. (default: undefined) */
    multiple?: number;
    /** Default order of sorted values. (default: null) */
    defaultOrder?: SortType;
    /** Trigger when sort button click */
    onSort?: (colKey: string, order: SortType) => any;
    /** Supported sort way (default: both) */
    sortDirections?: 'ascend' | 'descend' | 'both';
}
export interface Sorting extends SortOptions {
    key: string;
    type: SortType;
}
export type SortType = 'ascend' | 'descend' | null;
export interface SearchControl {
    /** Fields used to search when autoSearch = false (default: all) */
    fields?: 'all' | string[];
    /** Auto search when typing with (debounce: 250ms) */
    searchOnTyping?: boolean;
}
export type FilterType = 'number' | 'text' | 'date';
export interface FilterField {
    key: string;
    title: string;
    type: FilterType | SelectOption[];
}
export interface Filter {
    id: string;
    column?: string;
    op?: string;
    value?: any;
    logical?: string;
}
export interface FilterItemProp {
    filter: Filter;
    fields: FilterField[];
    hideDelIcon?: boolean;
    onFilterChange: (id: string, changedFilter: any) => void;
    onDelete: (id: string) => void;
}
export type RowFilterControl = {
    [key: string]: FilterType | SelectOption[];
};
export interface TableSearchProps extends ControlCommon {
    control: SearchControl;
    resetFlag: boolean;
    onSearch?: (keyword: string) => any;
}
export interface TableColFilterProps extends ControlCommon {
    selection?: boolean;
    columns: Array<Pick<TableColumn, 'key' | 'title'>>;
    onFilter: (hiddenCols: string[]) => void;
    resetFlag: boolean;
}
export interface TableRowFilterProps extends ControlCommon {
    control: RowFilterControl;
    columns: Array<Pick<TableColumn, 'key' | 'title'>>;
    onFilter: (filters: Filter[]) => any;
    resetFlag: boolean;
}
export interface TableExportProps extends ControlCommon {
    onExport: (type: 'pdf' | 'csv') => any;
}
interface TableRowOptions {
    /** even table selection = true, this row will also be unselectable (default: false)  */
    disabledSelection?: boolean;
    /** Customize tr element  */
    trProps?: React.HTMLAttributes<HTMLTableRowElement>;
}
export interface TableRow extends ExtendOption {
    key?: string | number;
    rowOptions?: TableRowOptions;
    groupKey?: string;
}
export interface TableColumn {
    /** Unique key of this column */
    key: string;
    /** Title of this column */
    title: string;
    /** th colSpan, set to 0, the cell will not be rendered. (default: -1) */
    colSpan?: number;
    /** The className of this column */
    thClassName?: string;
    /** Renderer content of the table cell. The return value should be a ReactNode (default: undefined) */
    render?: (value: any, record: TableRow, index: number) => React.ReactNode;
    /** Renderer customize prop of the table cell. The return value should be a ReactNode (default: undefined) */
    renderTdProps?: (value: any, record: TableRow, index: number) => React.DetailedHTMLProps<React.TdHTMLAttributes<HTMLTableCellElement>, HTMLTableCellElement>;
    /** The specify which way that column is aligned (default: left) */
    align?: 'left' | 'center' | 'right';
    /** Set max width to enable text-overflow: ellipsis, -1 to disabled. (default: -1) */
    maxWidth?: number;
    /** Column width (apply for table fixed or fixed column) */
    /** Set column to be fixed (default: undefined) */
    /** Setup sort option */
    sorter?: SortOptions;
}
interface TableGroup {
    key: string;
    label: React.ReactNode;
    defaultCollapse?: boolean;
    /** Show empty label if empty data (default: false) */
    showEmpty?: boolean;
}
export interface TableProps {
    columns: TableColumn[];
    rows?: TableRow[];
    /** Loading effect (default: false) */
    loading?: true | React.ReactNode;
    /** table-layout: fixed; (default: false) */
    fixedLayout?: boolean;
    /** Specify field in row is unique key (default: 'key') */
    keyField?: string;
    /** Border style (default: undefined) */
    bordered?: 'row' | 'column' | 'both';
    /** Change background color when hover (default: false) */
    hoverable?: boolean;
    /** Use striped to add zebra-striping to any table row within the tbody (default: undefined) */
    striped?: 'odd' | 'even';
    /** If true, compact vertical padding designed for keyboard and mouse input is used for the list and list items. The prop is available to descendant components as the dense context. (default: false) */
    dense?: boolean;
    /** Set the header sticky. (default: false) */
    stickyHeader?: boolean;
    /** Add table header */
    header?: React.ReactNode;
    /** (default: "No data available in table") */
    noData?: React.ReactNode;
    /** Custom group to collapse/expand (default: []) */
    groups?: TableGroup[];
    /** Allow row selection (default: selection: false, allowSelectAll: true) */
    selection?: boolean;
    allowSelectAll?: boolean;
    CheckboxProps?: React.ComponentProps<typeof Checkbox>;
    onRowSelectChange?: (selected: TableRow[], record?: TableRow) => any;
    /** If true, the table will automatically filter when the filter changes (default: true) */
    autoFilter?: boolean;
    /** Search control */
    searchControl?: SearchControl;
    /** Column filter control (default: false) */
    columnFilterControl?: boolean;
    /** Row filter control (default: false) */
    rowFilterControl?: RowFilterControl;
    /** Controls whether the control title is show (default: false) */
    showControlTitle?: boolean;
    /** Controls whether the reset filter button is show (default: true) */
    showResetFilter?: boolean;
    /** Trigger when the filter changes */
    onFilter?: (filter: OnFilterValue) => any;
    /** Allow export table to pdf to csv (default: false) */
    allowExport?: boolean;
    /** Add other control in control bar */
    additionalControl?: React.ReactNode;
    /** Custom pagination */
    PaginationProps?: Partial<PaginationProps>;
    paginationPosition?: 'flex-end' | 'center' | 'flex-start';
    /** Render table footer (summary) */
    summary?: React.ReactNode;
    /** Support translate */
    translation?: Translation;
    /** Add class name, style to the root element */
    className?: string;
    style?: React.CSSProperties;
    /** The ref is forwarded to the root element. */
    ref?: React.Ref<HTMLDivElement>;
}
export {};
